@@ -15,6 +15,7 @@ API_PATH = {
     "accept_mod_invite":       "r/{subreddit}/api/accept_moderator_invite",
     "add_subreddit_rule":      "api/add_subreddit_rule",
     "approve":                 "api/approve/",
+    "award_thing":             "api/v2/gold/gild",
     "block":                   "api/block",
     "block_user":              "/api/block_user/",
     "blocked":                 "prefs/blocked/",
@@ -33,6 +34,7 @@ API_PATH = {
     "comment_replies":         "message/comments/",
     "compose":                 "api/compose/",
     "contest_mode":            "api/set_contest_mode/",
+    "convert_rte_body":        "api/convert_rte_body_format",
     "del":                     "api/del/",
     "delete_message":          "api/del_msg",
     "delete_sr_banner":        "r/{subreddit}/api/delete_sr_banner",
@@ -60,7 +62,6 @@ API_PATH = {
     "friend":                  "r/{subreddit}/api/friend/",
     "friend_v1":               "api/v1/me/friends/{user}",
     "friends":                 "api/v1/me/friends/",
-    "gild_thing":              "api/v1/gold/gild/{fullname}/",
     "gild_user":               "api/v1/gold/give/{username}/",
     "hide":                    "api/hide/",
     "ignore_reports":          "api/ignore_reports/",
@@ -72,6 +73,7 @@ API_PATH = {
     "list_banned":             "r/{subreddit}/about/banned/",
     "list_contributor":        "r/{subreddit}/about/contributors/",
     "list_moderator":          "r/{subreddit}/about/moderators/",
+    "list_invited_moderator":  "/api/v1/{subreddit}/moderators_invited",
     "list_muted":              "r/{subreddit}/about/muted/",
     "list_wikibanned":         "r/{subreddit}/about/wikibanned/",
     "list_wikicontributor":    "r/{subreddit}/about/wikicontributors/",
@@ -163,6 +165,7 @@ API_PATH = {
     "submission":              "comments/{id}/",
     "submission_replies":      "message/selfreply/",
     "submit":                  "api/submit/",
+    "submit_gallery_post":     "api/submit_gallery_post.json",
     "submit_poll_post":        "api/submit_poll_post",
     "subreddit":               "r/{subreddit}/",
     "subreddit_about":         "r/{subreddit}/about/",
@@ -173,7 +176,7 @@ API_PATH = {
     "subreddit_stylesheet":    "r/{subreddit}/api/subreddit_stylesheet/",
     "subreddits_by_topic":     "api/subreddits_by_topic",
     "subreddits_default":      "subreddits/default/",
-    "subreddits_gold":         "subreddits/gold/",
+    "subreddits_gold":         "subreddits/premium/",
     "subreddits_name_search":  "api/search_reddit_names/",
     "subreddits_new":          "subreddits/new/",
     "subreddits_popular":      "subreddits/popular/",
