@@ -7,8 +7,7 @@ from .listing.generator import ListingGenerator
 from .util import stream_generator
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .reddit.comment import Comment  # noqa: F401
-    from .reddit.message import Message
+    from ... import praw
 
 
 class Inbox(PRAWBase):
@@ -16,7 +15,7 @@ class Inbox(PRAWBase):
 
     def all(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator[Union["Message", "Comment"]]:
+    ) -> Iterator[Union["praw.models.Message", "praw.models.Comment"]]:
         """Return a :class:`.ListingGenerator` for all inbox comments and messages.
 
         Additional keyword arguments are passed in the initialization of
@@ -26,13 +25,13 @@ class Inbox(PRAWBase):
 
         .. code-block:: python
 
-           for item in reddit.inbox.all(limit=None):
-               print(repr(item))
+            for item in reddit.inbox.all(limit=None):
+                print(repr(item))
 
         """
         return ListingGenerator(self._reddit, API_PATH["inbox"], **generator_kwargs)
 
-    def collapse(self, items: List["Message"]):
+    def collapse(self, items: List["praw.models.Message"]):
         """Mark an inbox message as collapsed.
 
         :param items: A list containing instances of :class:`.Message`.
@@ -44,6 +43,7 @@ class Inbox(PRAWBase):
         .. code-block:: python
 
             from praw.models import Message
+
             unread_messages = []
             for item in reddit.inbox.unread(limit=None):
                 if isinstance(item, Message):
@@ -52,7 +52,7 @@ class Inbox(PRAWBase):
 
         .. seealso::
 
-           :meth:`.Message.uncollapse`
+            :meth:`.Message.uncollapse`
 
         """
         while items:
@@ -62,7 +62,7 @@ class Inbox(PRAWBase):
 
     def comment_replies(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Comment"]:
+    ) -> Iterator["praw.models.Comment"]:
         """Return a :class:`.ListingGenerator` for comment replies.
 
         Additional keyword arguments are passed in the initialization of
@@ -72,20 +72,22 @@ class Inbox(PRAWBase):
 
         .. code-block:: python
 
-           for reply in reddit.inbox.comment_replies():
-               print(reply.author)
+            for reply in reddit.inbox.comment_replies():
+                print(reply.author)
 
         """
         return ListingGenerator(
             self._reddit, API_PATH["comment_replies"], **generator_kwargs
         )
 
-    def mark_read(self, items: List[Union["Comment", "Message"]]):
+    def mark_read(
+        self, items: List[Union["praw.models.Comment", "praw.models.Message"]]
+    ):
         """Mark Comments or Messages as read.
 
         :param items: A list containing instances of :class:`.Comment` and/or
-            :class:`.Message` to be be marked as read relative to the
-            authorized user's inbox.
+            :class:`.Message` to be be marked as read relative to the authorized user's
+            inbox.
 
         Requests are batched at 25 items (reddit limit).
 
@@ -94,6 +96,7 @@ class Inbox(PRAWBase):
         .. code-block:: python
 
             from praw.models import Message
+
             unread_messages = []
             for item in reddit.inbox.unread(limit=None):
                 if isinstance(item, Message):
@@ -102,7 +105,7 @@ class Inbox(PRAWBase):
 
         .. seealso::
 
-           :meth:`.Comment.mark_read` and :meth:`.Message.mark_read`
+            :meth:`.Comment.mark_read` and :meth:`.Message.mark_read`
 
         """
         while items:
@@ -110,12 +113,14 @@ class Inbox(PRAWBase):
             self._reddit.post(API_PATH["read_message"], data=data)
             items = items[25:]
 
-    def mark_unread(self, items: List[Union["Comment", "Message"]]):
+    def mark_unread(
+        self, items: List[Union["praw.models.Comment", "praw.models.Message"]]
+    ):
         """Unmark Comments or Messages as read.
 
         :param items: A list containing instances of :class:`.Comment` and/or
-            :class:`.Message` to be be marked as unread relative to the
-            authorized user's inbox.
+            :class:`.Message` to be be marked as unread relative to the authorized
+            user's inbox.
 
         Requests are batched at 25 items (reddit limit).
 
@@ -128,7 +133,7 @@ class Inbox(PRAWBase):
 
         .. seealso::
 
-           :meth:`.Comment.mark_unread` and :meth:`.Message.mark_unread`
+            :meth:`.Comment.mark_unread` and :meth:`.Message.mark_unread`
 
         """
         while items:
@@ -138,27 +143,26 @@ class Inbox(PRAWBase):
 
     def mentions(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Comment"]:
+    ) -> Iterator["praw.models.Comment"]:
         r"""Return a :class:`.ListingGenerator` for mentions.
 
-        A mention is :class:`.Comment` in which the authorized redditor is
-        named in its body like ``/u/redditor_name``.
+        A mention is :class:`.Comment` in which the authorized redditor is named in its
+        body like ``u/redditor_name``.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        For example, to output the author and body of the first 25 mentions
-        try:
+        For example, to output the author and body of the first 25 mentions try:
 
         .. code-block:: python
 
-           for mention in reddit.inbox.mentions(limit=25):
-               print("{}\n{}\n".format(mention.author, mention.body))
+            for mention in reddit.inbox.mentions(limit=25):
+                print(f"{mention.author}\n{mention.body}\n")
 
         """
         return ListingGenerator(self._reddit, API_PATH["mentions"], **generator_kwargs)
 
-    def message(self, message_id: str) -> "Message":
+    def message(self, message_id: str) -> "praw.models.Message":
         """Return a Message corresponding to ``message_id``.
 
         :param message_id: The base36 id of a message.
@@ -167,7 +171,7 @@ class Inbox(PRAWBase):
 
         .. code-block:: python
 
-           message = reddit.inbox.message("7bnlgu")
+            message = reddit.inbox.message("7bnlgu")
 
         """
         listing = self._reddit.get(API_PATH["message"].format(id=message_id))
@@ -179,7 +183,7 @@ class Inbox(PRAWBase):
 
     def messages(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Message"]:
+    ) -> Iterator["praw.models.Message"]:
         """Return a :class:`.ListingGenerator` for inbox messages.
 
         Additional keyword arguments are passed in the initialization of
@@ -189,38 +193,37 @@ class Inbox(PRAWBase):
 
         .. code-block:: python
 
-           for message in reddit.inbox.messages(limit=5):
-               print(message.subject)
+            for message in reddit.inbox.messages(limit=5):
+                print(message.subject)
 
         """
         return ListingGenerator(self._reddit, API_PATH["messages"], **generator_kwargs)
 
     def sent(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Message"]:
+    ) -> Iterator["praw.models.Message"]:
         """Return a :class:`.ListingGenerator` for sent messages.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        For example, to output the recipient of the most recent 15 messages
-        try:
+        For example, to output the recipient of the most recent 15 messages try:
 
         .. code-block:: python
 
-           for message in reddit.inbox.sent(limit=15):
-               print(message.dest)
+            for message in reddit.inbox.sent(limit=15):
+                print(message.dest)
 
         """
         return ListingGenerator(self._reddit, API_PATH["sent"], **generator_kwargs)
 
     def stream(
         self, **stream_options: Union[str, int, Dict[str, str]]
-    ) -> Iterator[Union["Comment", "Message"]]:
+    ) -> Iterator[Union["praw.models.Comment", "praw.models.Message"]]:
         """Yield new inbox items as they become available.
 
-        Items are yielded oldest first. Up to 100 historical items will
-        initially be returned.
+        Items are yielded oldest first. Up to 100 historical items will initially be
+        returned.
 
         Keyword arguments are passed to :func:`.stream_generator`.
 
@@ -228,15 +231,15 @@ class Inbox(PRAWBase):
 
         .. code-block:: python
 
-           for item in reddit.inbox.stream():
-               print(item)
+            for item in reddit.inbox.stream():
+                print(item)
 
         """
         return stream_generator(self.unread, **stream_options)
 
     def submission_replies(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Comment"]:
+    ) -> Iterator["praw.models.Comment"]:
         """Return a :class:`.ListingGenerator` for submission replies.
 
         Additional keyword arguments are passed in the initialization of
@@ -246,15 +249,15 @@ class Inbox(PRAWBase):
 
         .. code-block:: python
 
-           for reply in reddit.inbox.submission_replies():
-               print(reply.author)
+            for reply in reddit.inbox.submission_replies():
+                print(reply.author)
 
         """
         return ListingGenerator(
             self._reddit, API_PATH["submission_replies"], **generator_kwargs
         )
 
-    def uncollapse(self, items: List["Message"]):
+    def uncollapse(self, items: List["praw.models.Message"]):
         """Mark an inbox message as uncollapsed.
 
         :param items: A list containing instances of :class:`.Message`.
@@ -266,6 +269,7 @@ class Inbox(PRAWBase):
         .. code-block:: python
 
             from praw.models import Message
+
             unread_messages = []
             for item in reddit.inbox.unread(limit=None):
                 if isinstance(item, Message):
@@ -274,7 +278,7 @@ class Inbox(PRAWBase):
 
         .. seealso::
 
-           :meth:`.Message.collapse`
+            :meth:`.Message.collapse`
 
         """
         while items:
@@ -286,13 +290,15 @@ class Inbox(PRAWBase):
         self,
         mark_read: bool = False,
         **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator[Union["Comment", "Message"]]:
+    ) -> Iterator[Union["praw.models.Comment", "praw.models.Message"]]:
         """Return a :class:`.ListingGenerator` for unread comments and messages.
 
         :param mark_read: Marks the inbox as read (default: False).
 
-        .. note:: This only marks the inbox as read not the messages. Use
-                  :meth:`.Inbox.mark_read` to mark the messages.
+        .. note::
+
+            This only marks the inbox as read not the messages. Use
+            :meth:`.Inbox.mark_read` to mark the messages.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -301,10 +307,11 @@ class Inbox(PRAWBase):
 
         .. code-block:: python
 
-           from praw.models import Comment
-           for item in reddit.inbox.unread(limit=None):
-               if isinstance(item, Comment):
-                   print(item.author)
+            from praw.models import Comment
+
+            for item in reddit.inbox.unread(limit=None):
+                if isinstance(item, Comment):
+                    print(item.author)
 
         """
         self._safely_add_arguments(generator_kwargs, "params", mark=mark_read)
