@@ -1,11 +1,12 @@
 """Provide the SubmissionListingMixin class."""
-from typing import Dict, Generator, TypeVar, Union
+from typing import TYPE_CHECKING, Dict, Iterator, Union
 
 from ....const import API_PATH
 from ...base import PRAWBase
 from ..generator import ListingGenerator
 
-Submission = TypeVar("Submission")
+if TYPE_CHECKING:  # pragma: no cover
+    from ..... import praw
 
 
 class SubmissionListingMixin(PRAWBase):
@@ -13,7 +14,7 @@ class SubmissionListingMixin(PRAWBase):
 
     def duplicates(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Generator[Submission, None, None]:
+    ) -> Iterator["praw.models.Submission"]:
         """Return a :class:`.ListingGenerator` for the submission's duplicates.
 
         Additional keyword arguments are passed in the initialization of
@@ -23,12 +24,15 @@ class SubmissionListingMixin(PRAWBase):
 
         .. code-block:: python
 
-           submission = reddit.submission(id='5or86n')
+            submission = reddit.submission(id="5or86n")
 
-           for duplicate in submission.duplicates():
-               # process each duplicate
+            for duplicate in submission.duplicates():
+                # process each duplicate
+                ...
 
-        .. seealso:: :meth:`~.upvote`
+        .. seealso::
+
+            :meth:`~.upvote`
 
         """
         url = API_PATH["duplicates"].format(submission_id=self.id)
