@@ -5,7 +5,7 @@ from typing import TYPE_CHECKING, Dict, Union
 from ..const import API_PATH
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .. import Reddit
+    from ... import praw
 
 
 class Preferences:
@@ -32,7 +32,7 @@ class Preferences:
         """
         return self._reddit.get(API_PATH["preferences"])
 
-    def __init__(self, reddit: "Reddit"):
+    def __init__(self, reddit: "praw.Reddit"):
         """Create a Preferences instance.
 
         :param reddit: The Reddit instance.
@@ -42,6 +42,8 @@ class Preferences:
     def update(self, **preferences: Union[bool, int, str]):
         """Modify the specified settings.
 
+        :param accept_pms: Who can send you personal messages (one of ``everyone``,
+            ``whitelisted``).
         :param activity_relevant_ads: Allow Reddit to use your activity on Reddit to
             show you more relevant advertisements (boolean).
         :param allow_clicktracking: Allow Reddit to log my outbound clicks for
@@ -50,18 +52,27 @@ class Preferences:
         :param clickgadget: Show me links I've recently viewed (boolean).
         :param collapse_read_messages: Collapse messages after I've read them (boolean).
         :param compress: Compress the link display (boolean).
+        :param creddit_autorenew: Use a creddit to automatically renew my gold if it
+            expires (boolean).
         :param default_comment_sort: Default comment sort (one of ``"confidence"``,
             ``"top"``, ``"new"``, ``"controversial"``, ``"old"``, ``"random"``,
             ``"qa"``, ``"live"``).
-        :param default_theme_sr: Theme selector (subreddit name).
-        :param design_beta: In redesign beta (boolean).
         :param domain_details: Show additional details in the domain text when
             available, such as the source subreddit or the content author's url/name
             (boolean).
+        :param email_chat_request: Send chat requests as emails (boolean).
+        :param email_comment_reply: Send comment replies as emails (boolean).
         :param email_digests: Send email digests (boolean).
         :param email_messages: Send messages as emails (boolean).
+        :param email_post_reply: Send post replies as emails (boolean).
+        :param email_private_message: Send private messages as emails (boolean).
         :param email_unsubscribe_all: Unsubscribe from all emails (boolean).
+        :param email_upvote_comment: Send comment upvote updates as emails (boolean).
+        :param email_upvote_post: Send post upvote updates as emails (boolean).
+        :param email_user_new_follower: Send new follower alerts as emails (boolean).
+        :param email_username_mention: Send username mentions as emails (boolean).
         :param enable_default_themes: Use reddit theme (boolean).
+        :param feed_recommendations_enabled: Enable feed recommendations (boolean).
         :param geopopular: Location (one of ``"GLOBAL"``, ``"AR"``, ``"AU"``, ``"BG"``,
             ``"CA"``, ``"CL"``, ``"CO"``, ``"CZ"``, ``"FI"``, ``"GB"``, ``"GR"``,
             ``"HR"``, ``"HU"``, ``"IE"``, ``"IN"``, ``"IS"``, ``"JP"``, ``"MX"``,
@@ -89,6 +100,7 @@ class Preferences:
             (boolean).
         :param highlight_new_comments: Highlight new comments (boolean).
         :param ignore_suggested_sort: Ignore suggested sorts (boolean).
+        :param in_redesign_beta: In redesign beta (boolean).
         :param label_nsfw: Label posts that are not safe for work (boolean).
         :param lang: Interface language (IETF language tag, underscore separated).
         :param legacy_search: Show legacy search page (boolean).
@@ -104,14 +116,15 @@ class Preferences:
             number (int between ``-100`` and ``100``).
         :param monitor_mentions: Notify me when people say my username (boolean).
         :param newwindow: Open links in a new window (boolean).
+        :param nightmode: Enable night mode (boolean).
         :param no_profanity: Don't show thumbnails or media previews for anything
             labeled NSFW (boolean).
-        :param video_autoplay: Autoplay Reddit videos on the desktop comments page
-            (boolean).
         :param num_comments: Display this many comments by default (int between ``1``
             and ``500``).
         :param numsites: Number of links to display at once (int between ``1`` and
             ``100``).
+        :param organic: Show the spotlight box on the home feed (boolean).
+        :param other_theme: Subreddit theme to use (subreddit name).
         :param over_18: I am over eighteen years old and willing to view adult content
             (boolean).
         :param private_feeds: Enable private RSS feeds (boolean).
@@ -121,23 +134,36 @@ class Preferences:
         :param research: Allow my data to be used for research purposes (boolean).
         :param search_include_over_18: Include not safe for work (NSFW) search results
             in searches (boolean).
+        :param send_crosspost_messages: Send crosspost messages (boolean).
+        :param send_welcome_messages: Send welcome messages (boolean).
         :param show_flair: Show user flair (boolean).
         :param show_gold_expiration: Show how much gold you have remaining on your
             userpage (boolean).
         :param show_link_flair: Show link flair (boolean).
+        :param show_location_based_recommendations: Show location based recommendations
+            (boolean).
+        :param show_presence: Show presence (boolean).
+        :param show_promote: Show promote (boolean).
         :param show_stylesheets: Allow subreddits to show me custom themes (boolean).
         :param show_trending: Show trending subreddits on the home feed (boolean).
-        :param store_visits: Store visits (boolean)
+        :param show_twitter: Show a link to your Twitter account on your profile
+            (boolean).
+        :param store_visits: Store visits (boolean).
+        :param theme_selector: Theme selector (subreddit name).
         :param third_party_data_personalized_ads: Allow Reddit to use data provided by
             third-parties to show you more relevant advertisements on Reddit (boolean).
+        :param third_party_personalized_ads: Allow personalization of advertisements
+            (boolean).
         :param third_party_site_data_personalized_ads: Allow personalization of
             advertisements using third-party website data (boolean).
         :param third_party_site_data_personalized_content: Allow personalization of
             content using third-party website data (boolean).
-        :param threaded_messages: Show message conversations in the inbox (boolean).
+        :param threaded_messages: Show message conversations in the inbox ( boolean).
         :param threaded_modmail: Enable threaded modmail display (boolean).
         :param top_karma_subreddits: Top karma subreddits (boolean).
         :param use_global_defaults: Use global defaults (boolean).
+        :param video_autoplay: Autoplay Reddit videos on the desktop comments page
+            (boolean).
 
         Additional keyword arguments can be provided to handle new settings as Reddit
         introduces them.
