@@ -11,8 +11,7 @@ from .mixins import FullnameMixin
 from .redditor import Redditor
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
-    from .submission import Submission  # noqa: F401
+    from .... import praw
 
 
 class LiveContributorRelationship:
@@ -24,32 +23,34 @@ class LiveContributorRelationship:
             permissions = {"all"}
         else:
             permissions = set(permissions)
-        return ",".join("+{}".format(x) for x in permissions)
+        return ",".join(f"+{x}" for x in permissions)
 
-    def __call__(self) -> List[Redditor]:
+    def __call__(self) -> List["praw.models.Redditor"]:
         """Return a :class:`.RedditorList` for live threads' contributors.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           for contributor in thread.contributor():
-               print(contributor)
+            thread = reddit.live("ukaeu1ik4sw5")
+            for contributor in thread.contributor():
+                print(contributor)
 
         """
         url = API_PATH["live_contributors"].format(id=self.thread.id)
         temp = self.thread._reddit.get(url)
         return temp if isinstance(temp, RedditorList) else temp[0]
 
-    def __init__(self, thread: "LiveThread"):
+    def __init__(self, thread: "praw.models.LiveThread"):
         """Create a :class:`.LiveContributorRelationship` instance.
 
         :param thread: An instance of :class:`.LiveThread`.
 
-        .. note:: This class should not be initialized directly. Instead obtain
-           an instance via: ``thread.contributor`` where ``thread`` is a
-           :class:`.LiveThread` instance.
+        .. note::
+
+            This class should not be initialized directly. Instead obtain an instance
+            via: ``thread.contributor`` where ``thread`` is a :class:`.LiveThread`
+            instance.
 
         """
         self.thread = thread
@@ -69,30 +70,34 @@ class LiveContributorRelationship:
         self.thread._reddit.post(url)
 
     def invite(
-        self, redditor: Union[str, Redditor], permissions: Optional[List[str]] = None
+        self,
+        redditor: Union[str, "praw.models.Redditor"],
+        permissions: Optional[List[str]] = None,
     ):
         """Invite a redditor to be a contributor of the live thread.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or
-            :class:`~.Redditor` instance.
-        :param permissions: When provided (not ``None``), permissions should
-            be a list of strings specifying which subset of permissions to
-            grant. An empty list ``[]`` indicates no permissions, and when
-            not provided (``None``), indicates full permissions.
+        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
+            instance.
+        :param permissions: When provided (not ``None``), permissions should be a list
+            of strings specifying which subset of permissions to grant. An empty list
+            ``[]`` indicates no permissions, and when not provided (``None``), indicates
+            full permissions.
         :raises: :class:`.RedditAPIException` if the invitation already exists.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           redditor = reddit.redditor("spez")
+            thread = reddit.live("ukaeu1ik4sw5")
+            redditor = reddit.redditor("spez")
 
-           # "manage" and "settings" permissions
-           thread.contributor.invite(redditor, ["manage", "settings"])
+            # "manage" and "settings" permissions
+            thread.contributor.invite(redditor, ["manage", "settings"])
 
-        .. seealso:: :meth:`.LiveContributorRelationship.remove_invite` to
-            remove the invite for redditor.
+        .. seealso::
+
+            :meth:`.LiveContributorRelationship.remove_invite` to remove the invite for
+            redditor.
 
         """
         url = API_PATH["live_invite"].format(id=self.thread.id)
@@ -117,7 +122,7 @@ class LiveContributorRelationship:
         url = API_PATH["live_leave"].format(id=self.thread.id)
         self.thread._reddit.post(url)
 
-    def remove(self, redditor: Union[str, Redditor]):
+    def remove(self, redditor: Union[str, "praw.models.Redditor"]):
         """Remove the redditor from the live thread contributors.
 
         :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or
@@ -127,10 +132,10 @@ class LiveContributorRelationship:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           redditor = reddit.redditor("spez")
-           thread.contributor.remove(redditor)
-           thread.contributor.remove("t2_1w72")  # with fullname
+            thread = reddit.live("ukaeu1ik4sw5")
+            redditor = reddit.redditor("spez")
+            thread.contributor.remove(redditor)
+            thread.contributor.remove("t2_1w72")  # with fullname
 
         """
         if isinstance(redditor, Redditor):
@@ -141,7 +146,7 @@ class LiveContributorRelationship:
         url = API_PATH["live_remove_contrib"].format(id=self.thread.id)
         self.thread._reddit.post(url, data=data)
 
-    def remove_invite(self, redditor: Union[str, Redditor]):
+    def remove_invite(self, redditor: Union[str, "praw.models.Redditor"]):
         """Remove the invite for redditor.
 
         :param redditor: A redditor fullname (e.g., ``"t2_1w72"``) or
@@ -151,13 +156,15 @@ class LiveContributorRelationship:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           redditor = reddit.redditor("spez")
-           thread.contributor.remove_invite(redditor)
-           thread.contributor.remove_invite("t2_1w72")  # with fullname
+            thread = reddit.live("ukaeu1ik4sw5")
+            redditor = reddit.redditor("spez")
+            thread.contributor.remove_invite(redditor)
+            thread.contributor.remove_invite("t2_1w72")  # with fullname
 
-        .. seealso:: :meth:`.LiveContributorRelationship.invite` to
-            invite a redditor to be a contributor of the live thread.
+        .. seealso::
+
+            :meth:`.LiveContributorRelationship.invite` to invite a redditor to be a
+            contributor of the live thread.
 
         """
         if isinstance(redditor, Redditor):
@@ -169,37 +176,38 @@ class LiveContributorRelationship:
         self.thread._reddit.post(url, data=data)
 
     def update(
-        self, redditor: Union[str, Redditor], permissions: Optional[List[str]] = None
+        self,
+        redditor: Union[str, "praw.models.Redditor"],
+        permissions: Optional[List[str]] = None,
     ):
         """Update the contributor permissions for ``redditor``.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or
-            :class:`~.Redditor` instance.
-        :param permissions: When provided (not ``None``), permissions should
-            be a list of strings specifying which subset of permissions to
-            grant (other permissions are removed). An empty list ``[]``
-            indicates no permissions, and when not provided (``None``),
-            indicates full permissions.
+        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
+            instance.
+        :param permissions: When provided (not ``None``), permissions should be a list
+            of strings specifying which subset of permissions to grant (other
+            permissions are removed). An empty list ``[]`` indicates no permissions, and
+            when not provided (``None``), indicates full permissions.
 
         For example, to grant all permissions to the contributor, try:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           thread.contributor.update("spez")
+            thread = reddit.live("ukaeu1ik4sw5")
+            thread.contributor.update("spez")
 
-        To grant ``"access"`` and ``"edit"`` permissions (and to
-        remove other permissions), try:
+        To grant ``"access"`` and ``"edit"`` permissions (and to remove other
+        permissions), try:
 
         .. code-block:: python
 
-           thread.contributor.update("spez", ["access", "edit"])
+            thread.contributor.update("spez", ["access", "edit"])
 
         To remove all permissions from the contributor, try:
 
         .. code-block:: python
 
-           subreddit.moderator.update("spez", [])
+            subreddit.moderator.update("spez", [])
 
         """
         url = API_PATH["live_update_perms"].format(id=self.thread.id)
@@ -211,37 +219,38 @@ class LiveContributorRelationship:
         self.thread._reddit.post(url, data=data)
 
     def update_invite(
-        self, redditor: Union[str, Redditor], permissions: Optional[List[str]] = None
+        self,
+        redditor: Union[str, "praw.models.Redditor"],
+        permissions: Optional[List[str]] = None,
     ):
         """Update the contributor invite permissions for ``redditor``.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or
-            :class:`~.Redditor` instance.
-        :param permissions: When provided (not ``None``), permissions should
-            be a list of strings specifying which subset of permissions to
-            grant (other permissions are removed). An empty list ``[]``
-            indicates no permissions, and when not provided (``None``),
-            indicates full permissions.
+        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
+            instance.
+        :param permissions: When provided (not ``None``), permissions should be a list
+            of strings specifying which subset of permissions to grant (other
+            permissions are removed). An empty list ``[]`` indicates no permissions, and
+            when not provided (``None``), indicates full permissions.
 
         For example, to set all permissions to the invitation, try:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           thread.contributor.update_invite("spez")
+            thread = reddit.live("ukaeu1ik4sw5")
+            thread.contributor.update_invite("spez")
 
-        To set "access" and "edit" permissions (and to remove other
-        permissions) to the invitation, try:
+        To set "access" and "edit" permissions (and to remove other permissions) to the
+        invitation, try:
 
         .. code-block:: python
 
-           thread.contributor.update_invite("spez", ["access", "edit"])
+            thread.contributor.update_invite("spez", ["access", "edit"])
 
         To remove all permissions from the invitation, try:
 
         .. code-block:: python
 
-           thread.contributor.update_invite("spez", [])
+            thread.contributor.update_invite("spez", [])
 
         """
         url = API_PATH["live_update_perms"].format(id=self.thread.id)
@@ -258,23 +267,21 @@ class LiveThread(RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
+    ======================= =========================================================
     Attribute               Description
-    ======================= ===================================================
-    ``created_utc``         The creation time of the live thread, in `Unix
-                            Time`_.
+    ======================= =========================================================
+    ``created_utc``         The creation time of the live thread, in `Unix Time`_.
     ``description``         Description of the live thread, as Markdown.
     ``description_html``    Description of the live thread, as HTML.
     ``id``                  The ID of the live thread.
-    ``nsfw``                A ``bool`` representing whether or not the live
-                            thread is marked as NSFW.
-    ======================= ===================================================
+    ``nsfw``                A ``bool`` representing whether or not the live thread is
+                            marked as NSFW.
+    ======================= =========================================================
 
     .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
     """
@@ -282,54 +289,53 @@ class LiveThread(RedditBase):
     STR_FIELD = "id"
 
     @cachedproperty
-    def contrib(self) -> "LiveThreadContribution":
+    def contrib(self) -> "praw.models.reddit.live.LiveThreadContribution":
         """Provide an instance of :class:`.LiveThreadContribution`.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           thread.contrib.add("### update")
+            thread = reddit.live("ukaeu1ik4sw5")
+            thread.contrib.add("### update")
 
         """
         return LiveThreadContribution(self)
 
     @cachedproperty
-    def contributor(self) -> LiveContributorRelationship:
+    def contributor(self) -> "praw.models.reddit.live.LiveContributorRelationship":
         """Provide an instance of :class:`.LiveContributorRelationship`.
 
-        You can call the instance to get a list of contributors which is
-        represented as :class:`.RedditorList` instance consists of
-        :class:`.Redditor` instances. Those Redditor instances have
-        ``permissions`` attributes as contributors:
+        You can call the instance to get a list of contributors which is represented as
+        :class:`.RedditorList` instance consists of :class:`.Redditor` instances. Those
+        Redditor instances have ``permissions`` attributes as contributors:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           for contributor in thread.contributor():
-               # prints `(Redditor(name="Acidtwist"), ["all"])`
-               print(contributor, contributor.permissions)
+            thread = reddit.live("ukaeu1ik4sw5")
+            for contributor in thread.contributor():
+                # prints `(Redditor(name="Acidtwist"), ["all"])`
+                print(contributor, contributor.permissions)
 
         """
         return LiveContributorRelationship(self)
 
     @cachedproperty
-    def stream(self) -> "LiveThreadStream":
+    def stream(self) -> "praw.models.reddit.live.LiveThreadStream":
         """Provide an instance of :class:`.LiveThreadStream`.
 
-        Streams are used to indefinitely retrieve new updates made to a
-        live thread, like:
+        Streams are used to indefinitely retrieve new updates made to a live thread,
+        like:
 
         .. code-block:: python
 
             for live_update in reddit.live("ta535s1hq2je").stream.updates():
                 print(live_update.body)
 
-        Updates are yielded oldest first as :class:`.LiveUpdate`. Up to 100
-        historical updates will initially be returned.
-        To only retrieve new updates starting from when the stream is
-        created, pass ``skip_existing=True``:
+        Updates are yielded oldest first as :class:`.LiveUpdate`. Up to 100 historical
+        updates will initially be returned.
+        To only retrieve new updates starting from when the stream is created, pass
+        ``skip_existing=True``:
 
         .. code-block:: python
 
@@ -340,16 +346,19 @@ class LiveThread(RedditBase):
         """
         return LiveThreadStream(self)
 
-    def __eq__(self, other: Union[str, "LiveThread"]) -> bool:
+    def __eq__(self, other: Union[str, "praw.models.LiveThread"]) -> bool:
         """Return whether the other instance equals the current.
 
-        .. note:: This comparison is case sensitive.
+        .. note::
+
+            This comparison is case sensitive.
+
         """
         if isinstance(other, str):
             return other == str(self)
         return isinstance(other, self.__class__) and str(self) == str(other)
 
-    def __getitem__(self, update_id: str) -> "LiveUpdate":
+    def __getitem__(self, update_id: str) -> "praw.models.LiveUpdate":
         """Return a lazy :class:`.LiveUpdate` instance.
 
         :param update_id: A live update ID, e.g.,
@@ -359,11 +368,12 @@ class LiveThread(RedditBase):
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           update = thread["7827987a-c998-11e4-a0b9-22000b6a88d2"]
-           update.thread     # LiveThread(id="ukaeu1ik4sw5")
-           update.id         # "7827987a-c998-11e4-a0b9-22000b6a88d2"
-           update.author     # "umbrae"
+            thread = reddit.live("ukaeu1ik4sw5")
+            update = thread["7827987a-c998-11e4-a0b9-22000b6a88d2"]
+            update.thread  # LiveThread(id="ukaeu1ik4sw5")
+            update.id  # "7827987a-c998-11e4-a0b9-22000b6a88d2"
+            update.author  # "umbrae"
+
         """
         return LiveUpdate(self._reddit, self.id, update_id)
 
@@ -373,7 +383,7 @@ class LiveThread(RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
+        reddit: "praw.Reddit",
         id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,  # pylint: disable=redefined-builtin
     ):
@@ -381,15 +391,16 @@ class LiveThread(RedditBase):
 
         :param reddit: An instance of :class:`.Reddit`.
         :param id: A live thread ID, e.g., ``"ukaeu1ik4sw5"``
+
         """
-        if bool(id) == bool(_data):
+        if (id, _data).count(None) != 1:
             raise TypeError("Either `id` or `_data` must be provided.")
-        super().__init__(reddit, _data=_data)
         if id:
             self.id = id
+        super().__init__(reddit, _data=_data)
 
     def _fetch_info(self):
-        return ("liveabout", {"id": self.id}, None)
+        return "liveabout", {"id": self.id}, None
 
     def _fetch_data(self):
         name, fields, params = self._fetch_info()
@@ -405,13 +416,13 @@ class LiveThread(RedditBase):
 
     def discussions(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["Submission"]:
+    ) -> Iterator["praw.models.Submission"]:
         """Get submissions linking to the thread.
 
-        :param generator_kwargs: keyword arguments passed to
-            :class:`.ListingGenerator` constructor.
-        :returns: A :class:`.ListingGenerator` object which yields
-            :class:`.Submission` object.
+        :param generator_kwargs: keyword arguments passed to :class:`.ListingGenerator`
+            constructor.
+        :returns: A :class:`.ListingGenerator` object which yields :class:`.Submission`
+            object.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -420,9 +431,9 @@ class LiveThread(RedditBase):
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           for submission in thread.discussions(limit=None):
-               print(submission.title)
+            thread = reddit.live("ukaeu1ik4sw5")
+            for submission in thread.discussions(limit=None):
+                print(submission.title)
 
         """
         url = API_PATH["live_discussions"].format(id=self.id)
@@ -431,16 +442,15 @@ class LiveThread(RedditBase):
     def report(self, type: str):  # pylint: disable=redefined-builtin
         """Report the thread violating the Reddit rules.
 
-        :param type: One of ``"spam"``, ``"vote-manipulation"``,
-            ``"personal-information"``, ``"sexualizing-minors"``,
-            ``"site-breaking"``.
+        :param type: One of ``"spam"``, ``"vote-manipulation"``, ``"personal-
+            information"``, ``"sexualizing-minors"``, ``"site-breaking"``.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live("xyu8kmjvfrww")
-           thread.report("spam")
+            thread = reddit.live("xyu8kmjvfrww")
+            thread.report("spam")
 
         """
         url = API_PATH["live_report"].format(id=self.id)
@@ -448,13 +458,13 @@ class LiveThread(RedditBase):
 
     def updates(
         self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["LiveUpdate"]:
+    ) -> Iterator["praw.models.LiveUpdate"]:
         """Return a :class:`.ListingGenerator` yields :class:`.LiveUpdate` s.
 
-        :param generator_kwargs: keyword arguments passed to
-            :class:`.ListingGenerator` constructor.
-        :returns: A :class:`.ListingGenerator` object which yields
-            :class:`.LiveUpdate` object.
+        :param generator_kwargs: keyword arguments passed to :class:`.ListingGenerator`
+            constructor.
+        :returns: A :class:`.ListingGenerator` object which yields :class:`.LiveUpdate`
+            object.
 
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
@@ -463,10 +473,10 @@ class LiveThread(RedditBase):
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           after = "LiveUpdate_fefb3dae-7534-11e6-b259-0ef8c7233633"
-           for submission in thread.updates(limit=5, params={"after": after}):
-               print(submission.body)
+            thread = reddit.live("ukaeu1ik4sw5")
+            after = "LiveUpdate_fefb3dae-7534-11e6-b259-0ef8c7233633"
+            for submission in thread.updates(limit=5, params={"after": after}):
+                print(submission.body)
 
         """
         url = API_PATH["live_updates"].format(id=self.id)
@@ -478,18 +488,18 @@ class LiveThread(RedditBase):
 class LiveThreadContribution:
     """Provides a set of contribution functions to a LiveThread."""
 
-    def __init__(self, thread: LiveThread):
+    def __init__(self, thread: "praw.models.LiveThread"):
         """Create an instance of :class:`.LiveThreadContribution`.
 
         :param thread: An instance of :class:`.LiveThread`.
 
-        This instance can be retrieved through ``thread.contrib``
-        where thread is a :class:`.LiveThread` instance. E.g.,
+        This instance can be retrieved through ``thread.contrib`` where thread is a
+        :class:`.LiveThread` instance. E.g.,
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           thread.contrib.add("### update")
+            thread = reddit.live("ukaeu1ik4sw5")
+            thread.contrib.add("### update")
 
         """
         self.thread = thread
@@ -503,8 +513,8 @@ class LiveThreadContribution:
 
         .. code-block:: python
 
-           thread = reddit.live("ydwwxneu7vsa")
-           thread.contrib.add("test `LiveThreadContribution.add()`")
+            thread = reddit.live("ydwwxneu7vsa")
+            thread.contrib.add("test `LiveThreadContribution.add()`")
 
         """
         url = API_PATH["live_add_update"].format(id=self.thread.id)
@@ -517,8 +527,8 @@ class LiveThreadContribution:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           thread.contrib.close()
+            thread = reddit.live("ukaeu1ik4sw5")
+            thread.contrib.close()
 
         """
         url = API_PATH["live_close"].format(id=self.thread.id)
@@ -530,41 +540,40 @@ class LiveThreadContribution:
         description: Optional[str] = None,
         nsfw: Optional[bool] = None,
         resources: Optional[str] = None,
-        **other_settings: Optional[str]
+        **other_settings: Optional[str],
     ):
         """Update settings of the live thread.
 
         :param title: (Optional) The title of the live thread (default: None).
-        :param description: (Optional) The live thread's description
+        :param description: (Optional) The live thread's description (default: None).
+        :param nsfw: (Optional) Indicate whether this thread is not safe for work
             (default: None).
-        :param nsfw: (Optional) Indicate whether this thread is not safe for
-            work (default: None).
-        :param resources: (Optional) Markdown formatted information that is
-            useful for the live thread (default: None).
+        :param resources: (Optional) Markdown formatted information that is useful for
+            the live thread (default: None).
 
         Does nothing if no arguments are provided.
 
         Each setting will maintain its current value if ``None`` is specified.
 
-        Additional keyword arguments can be provided to handle new settings as
-        Reddit introduces them.
+        Additional keyword arguments can be provided to handle new settings as Reddit
+        introduces them.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live("xyu8kmjvfrww")
+            thread = reddit.live("xyu8kmjvfrww")
 
-           # update `title` and `nsfw`
-           updated_thread = thread.contrib.update(title=new_title, nsfw=True)
+            # update `title` and `nsfw`
+            updated_thread = thread.contrib.update(title=new_title, nsfw=True)
 
-        If Reddit introduces new settings, you must specify ``None`` for the
-        setting you want to maintain:
+        If Reddit introduces new settings, you must specify ``None`` for the setting you
+        want to maintain:
 
         .. code-block:: python
 
-           # update `nsfw` and maintain new setting `foo`
-           thread.contrib.update(nsfw=True, foo=None)
+            # update `nsfw` and maintain new setting `foo`
+            thread.contrib.update(nsfw=True, foo=None)
 
         """
         settings = {
@@ -601,37 +610,39 @@ class LiveThreadStream:
 
     """
 
-    def __init__(self, live_thread: LiveThread):
+    def __init__(self, live_thread: "praw.models.LiveThread"):
         """Create a LiveThreadStream instance.
 
         :param live_thread: The live thread associated with the stream.
         """
         self.live_thread = live_thread
 
-    def updates(self, **stream_options: Dict[str, Any]) -> Iterator["LiveUpdate"]:
+    def updates(
+        self, **stream_options: Dict[str, Any]
+    ) -> Iterator["praw.models.LiveUpdate"]:
         """Yield new updates to the live thread as they become available.
 
-        :param skip_existing: Set to ``True`` to only fetch items created
-            after the stream (default: ``False``).
+        :param skip_existing: Set to ``True`` to only fetch items created after the
+            stream (default: ``False``).
 
         As with :meth:`.LiveThread.updates()`, updates are yielded as
         :class:`.LiveUpdate`.
 
-        Updates are yielded oldest first. Up to 100 historical updates will
-        initially be returned.
+        Updates are yielded oldest first. Up to 100 historical updates will initially be
+        returned.
 
         Keyword arguments are passed to :func:`.stream_generator`.
 
-        For example, to retrieve all new updates made to the
-        ``"ta535s1hq2je"`` live thread, try:
+        For example, to retrieve all new updates made to the ``"ta535s1hq2je"`` live
+        thread, try:
 
         .. code-block:: python
 
             for live_update in reddit.live("ta535s1hq2je").stream.updates():
                 print(live_update.body)
 
-        To only retrieve new updates starting from when the stream is
-        created, pass ``skip_existing=True``:
+        To only retrieve new updates starting from when the stream is created, pass
+        ``skip_existing=True``:
 
         .. code-block:: python
 
@@ -648,22 +659,21 @@ class LiveUpdate(FullnameMixin, RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
+    ======================= ============================================================
     Attribute               Description
-    ======================= ===================================================
+    ======================= ============================================================
     ``author``              The :class:`.Redditor` who made the update.
     ``body``                Body of the update, as Markdown.
     ``body_html``           Body of the update, as HTML.
     ``created_utc``         The time the update was created, as `Unix Time`_.
-    ``stricken``            A ``bool`` representing whether or not the update
-                            was stricken (see :meth:`.strike`).
-    ======================= ===================================================
+    ``stricken``            A ``bool`` representing whether or not the update was
+                            stricken (see :meth:`.strike`).
+    ======================= ============================================================
 
     .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
     """
@@ -672,16 +682,16 @@ class LiveUpdate(FullnameMixin, RedditBase):
     _kind = "LiveUpdate"
 
     @cachedproperty
-    def contrib(self) -> "LiveUpdateContribution":
+    def contrib(self) -> "praw.models.reddit.live.LiveUpdateContribution":
         """Provide an instance of :class:`.LiveUpdateContribution`.
 
         Usage:
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           update = thread["7827987a-c998-11e4-a0b9-22000b6a88d2"]
-           update.contrib  # LiveUpdateContribution instance
+            thread = reddit.live("ukaeu1ik4sw5")
+            update = thread["7827987a-c998-11e4-a0b9-22000b6a88d2"]
+            update.contrib  # LiveUpdateContribution instance
 
         """
         return LiveUpdateContribution(self)
@@ -693,15 +703,14 @@ class LiveUpdate(FullnameMixin, RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
+        reddit: "praw.Reddit",
         thread_id: Optional[str] = None,
         update_id: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
     ):
         """Initialize a lazy :class:`.LiveUpdate` instance.
 
-        Either ``thread_id`` and ``update_id``, or ``_data`` must be
-        provided.
+        Either ``thread_id`` and ``update_id``, or ``_data`` must be provided.
 
         :param reddit: An instance of :class:`.Reddit`.
         :param thread_id: A live thread ID, e.g., ``"ukaeu1ik4sw5"``.
@@ -712,22 +721,21 @@ class LiveUpdate(FullnameMixin, RedditBase):
 
         .. code-block:: python
 
-           update = LiveUpdate(reddit, "ukaeu1ik4sw5",
-                               "7827987a-c998-11e4-a0b9-22000b6a88d2")
-           update.thread     # LiveThread(id="ukaeu1ik4sw5")
-           update.id         # "7827987a-c998-11e4-a0b9-22000b6a88d2"
-           update.author     # "umbrae"
+            update = LiveUpdate(reddit, "ukaeu1ik4sw5", "7827987a-c998-11e4-a0b9-22000b6a88d2")
+            update.thread  # LiveThread(id="ukaeu1ik4sw5")
+            update.id  # "7827987a-c998-11e4-a0b9-22000b6a88d2"
+            update.author  # "umbrae"
+
         """
         if _data is not None:
-            # Since _data (part of JSON returned from reddit) have no
-            # thread ID, self._thread must be set by the caller of
-            # LiveUpdate(). See the code of LiveThread.updates() for example.
-            super().__init__(reddit, _data=_data)
-            self._fetched = True
+            # Since _data (part of JSON returned from reddit) have no thread ID,
+            # self._thread must be set by the caller of LiveUpdate(). See the code of
+            # LiveThread.updates() for example.
+            super().__init__(reddit, _data=_data, _fetched=True)
         elif thread_id and update_id:
+            self.id = update_id
             super().__init__(reddit, _data=None)
             self._thread = LiveThread(self._reddit, thread_id)
-            self.id = update_id
         else:
             raise TypeError(
                 "Either `thread_id` and `update_id`, or `_data` must be provided."
@@ -749,20 +757,20 @@ class LiveUpdate(FullnameMixin, RedditBase):
 class LiveUpdateContribution:
     """Provides a set of contribution functions to LiveUpdate."""
 
-    def __init__(self, update: LiveUpdate):
+    def __init__(self, update: "praw.models.LiveUpdate"):
         """Create an instance of :class:`.LiveUpdateContribution`.
 
         :param update: An instance of :class:`.LiveUpdate`.
 
-        This instance can be retrieved through ``update.contrib``
-        where update is a :class:`.LiveUpdate` instance. E.g.,
+        This instance can be retrieved through ``update.contrib`` where update is a
+        :class:`.LiveUpdate` instance. E.g.,
 
         .. code-block:: python
 
-           thread = reddit.live("ukaeu1ik4sw5")
-           update = thread["7827987a-c998-11e4-a0b9-22000b6a88d2"]
-           update.contrib  # LiveUpdateContribution instance
-           update.contrib.remove()
+            thread = reddit.live("ukaeu1ik4sw5")
+            update = thread["7827987a-c998-11e4-a0b9-22000b6a88d2"]
+            update.contrib  # LiveUpdateContribution instance
+            update.contrib.remove()
 
         """
         self.update = update
@@ -772,11 +780,11 @@ class LiveUpdateContribution:
 
         Usage:
 
-         .. code-block:: python
+        .. code-block:: python
 
-           thread = reddit.live("ydwwxneu7vsa")
-           update = thread["6854605a-efec-11e6-b0c7-0eafac4ff094"]
-           update.contrib.remove()
+            thread = reddit.live("ydwwxneu7vsa")
+            update = thread["6854605a-efec-11e6-b0c7-0eafac4ff094"]
+            update.contrib.remove()
 
         """
         url = API_PATH["live_remove_update"].format(id=self.update.thread.id)
@@ -788,14 +796,17 @@ class LiveUpdateContribution:
 
         .. code-block:: python
 
-           thread = reddit.live("xyu8kmjvfrww")
-           update = thread["cb5fe532-dbee-11e6-9a91-0e6d74fabcc4"]
-           update.contrib.strike()
+            thread = reddit.live("xyu8kmjvfrww")
+            update = thread["cb5fe532-dbee-11e6-9a91-0e6d74fabcc4"]
+            update.contrib.strike()
 
         To check whether the update is stricken or not, use ``update.stricken``
-        attribute. But note that accessing lazy attributes on updates
-        (includes ``update.stricken``) may raises ``AttributeError``.
-        See :class:`.LiveUpdate` for details.
+        attribute.
+
+        .. note::
+
+            Accessing lazy attributes on updates (includes ``update.stricken``) may
+            raise :py:class:`AttributeError`. See :class:`.LiveUpdate` for details.
 
         """
         url = API_PATH["live_strike"].format(id=self.update.thread.id)
