@@ -8,7 +8,7 @@ from .redditor import Redditor
 from .subreddit import Subreddit
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
+    from .... import praw
 
 
 class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
@@ -16,17 +16,17 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
+    ======================= ============================================================
     Attribute               Description
-    ======================= ===================================================
+    ======================= ============================================================
     ``author``              Provides an instance of :class:`.Redditor`.
-    ``body``                The body of the message.
+    ``body``                The body of the message, as Markdown.
+    ``body_html``           The body of the message, as HTML.
     ``created_utc``         Time the message was created, represented in
                             `Unix Time`_.
     ``dest``                Provides an instance of :class:`.Redditor`. The
@@ -35,7 +35,7 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
     ``name``                The full ID of the message, prefixed with ``t4_``.
     ``subject``             The subject of the message.
     ``was_comment``         Whether or not the message was a comment reply.
-    ======================= ===================================================
+    ======================= ============================================================
 
 
     .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
@@ -45,7 +45,7 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
     STR_FIELD = "id"
 
     @classmethod
-    def parse(cls, data: Dict[str, Any], reddit: "Reddit"):
+    def parse(cls, data: Dict[str, Any], reddit: "praw.Reddit"):
         """Return an instance of Message or SubredditMessage from ``data``.
 
         :param data: The structured data.
@@ -77,16 +77,17 @@ class Message(InboxableMixin, ReplyableMixin, FullnameMixin, RedditBase):
         """Return the class's kind."""
         return self._reddit.config.kinds["message"]
 
-    def __init__(self, reddit: "Reddit", _data: Dict[str, Any]):
+    def __init__(self, reddit: "praw.Reddit", _data: Dict[str, Any]):
         """Construct an instance of the Message object."""
-        super().__init__(reddit, _data=_data)
-        self._fetched = True
+        super().__init__(reddit, _data=_data, _fetched=True)
 
     def delete(self):
         """Delete the message.
 
-        .. note:: Reddit does not return an indication of whether or not the
-                  message was successfully deleted.
+        .. note::
+
+            Reddit does not return an indication of whether or not the message was
+            successfully deleted.
 
         For example, to delete the most recent message in your inbox:
 
@@ -103,28 +104,27 @@ class SubredditMessage(Message):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
+    ======================= ============================================================
     Attribute               Description
-    ======================= ===================================================
+    ======================= ============================================================
     ``author``              Provides an instance of :class:`.Redditor`.
-    ``body``                The body of the message.
-    ``created_utc``         Time the message was created, represented in
-                            `Unix Time`_.
-    ``dest``                Provides an instance of :class:`.Redditor`. The
-                            recipient of the message.
+    ``body``                The body of the message, as Markdown.
+    ``body_html``           The body of the message, as HTML.
+    ``created_utc``         Time the message was created, represented in `Unix Time`_.
+    ``dest``                Provides an instance of :class:`.Redditor`. The recipient of
+                            the message.
     ``id``                  The ID of the message.
     ``name``                The full ID of the message, prefixed with ``t4_``.
     ``subject``             The subject of the message.
-    ``subreddit``           If the message was sent from a subreddit,
-                            provides an instance of :class:`.Subreddit`.
+    ``subreddit``           If the message was sent from a subreddit, provides an
+                            instance of :class:`.Subreddit`.
     ``was_comment``         Whether or not the message was a comment reply.
-    ======================= ===================================================
+    ======================= ============================================================
 
     .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
 
@@ -139,9 +139,12 @@ class SubredditMessage(Message):
         .. code-block:: python
 
             from praw.models import SubredditMessage
-            msg = next(message for message in reddit.inbox.all()
-                        if isinstance(message, SubredditMessage)
+
+            msg = next(
+                message for message in reddit.inbox.all() if isinstance(message, SubredditMessage)
+            )
             msg.mute()
+
         """
         self._reddit.post(API_PATH["mute_sender"], data={"id": self.fullname})
 
@@ -154,8 +157,11 @@ class SubredditMessage(Message):
         .. code-block:: python
 
             from praw.models import SubredditMessage
-            msg = next(message for message in reddit.inbox.all()
-                        if isinstance(message, SubredditMessage)
+
+            msg = next(
+                message for message in reddit.inbox.all() if isinstance(message, SubredditMessage)
+            )
             msg.unmute()
+
         """
         self._reddit.post(API_PATH["unmute_sender"], data={"id": self.fullname})
