@@ -4,7 +4,7 @@ from typing import TYPE_CHECKING, Optional, Union
 from ....const import API_PATH
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ..subreddit import Subreddit  # noqa: F401
+    from ..... import praw
 
 
 class MessageableMixin:
@@ -14,43 +14,46 @@ class MessageableMixin:
         self,
         subject: str,
         message: str,
-        from_subreddit: Optional[Union["Subreddit", str]] = None,
+        from_subreddit: Optional[Union["praw.models.Subreddit", str]] = None,
     ):
-        """
-        Send a message to a redditor or a subreddit's moderators (mod mail).
+        """Send a message to a redditor or a subreddit's moderators (mod mail).
 
         :param subject: The subject of the message.
         :param message: The message content.
-        :param from_subreddit: A :class:`~.Subreddit` instance or string to
-            send the message from. When provided, messages are sent from
-            the subreddit rather than from the authenticated user.
-            Note that the authenticated user must be a moderator of the
-            subreddit and have the ``mail`` moderator permission.
+        :param from_subreddit: A :class:`~.Subreddit` instance or string to send the
+            message from. When provided, messages are sent from the subreddit rather
+            than from the authenticated user.
+
+            .. note::
+
+                The authenticated user must be a moderator of the subreddit and have the
+                ``mail`` moderator permission.
 
         For example, to send a private message to ``u/spez``, try:
 
         .. code-block:: python
 
-           reddit.redditor("spez").message("TEST", "test message from PRAW")
+            reddit.redditor("spez").message("TEST", "test message from PRAW")
 
         To send a message to ``u/spez`` from the moderators of ``r/test`` try:
 
         .. code-block:: python
 
-           reddit.redditor("spez").message("TEST", "test message from r/test",
-                                           from_subreddit="test")
+            reddit.redditor("spez").message(
+                "TEST", "test message from r/test", from_subreddit="test"
+            )
 
         To send a message to the moderators of ``r/test``, try:
 
         .. code-block:: python
 
-           reddit.subreddit("test").message("TEST", "test PM from PRAW")
+            reddit.subreddit("test").message("TEST", "test PM from PRAW")
 
         """
         data = {
             "subject": subject,
             "text": message,
-            "to": "{}{}".format(getattr(self.__class__, "MESSAGE_PREFIX", ""), self),
+            "to": f"{getattr(self.__class__, 'MESSAGE_PREFIX', '')}{self}",
         }
         if from_subreddit:
             data["from_sr"] = str(from_subreddit)
