@@ -6,7 +6,7 @@ from ...util import snake_case_keys
 from .base import RedditBase
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
+    from .... import praw
 
 
 class ModmailConversation(RedditBase):
@@ -14,41 +14,38 @@ class ModmailConversation(RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
+    ======================= ============================================================
     Attribute               Description
-    ======================= ===================================================
-    ``authors``             Provides an ordered list of :class:`.Redditor`
-                            instances. The authors of each message in the
-                            modmail conversation.
+    ======================= ============================================================
+    ``authors``             Provides an ordered list of :class:`.Redditor` instances.
+                            The authors of each message in the modmail conversation.
     ``id``                  The ID of the ModmailConversation.
-    ``is_highlighted``      Whether or not the ModmailConversation is
-                            highlighted.
-    ``is_internal``         Whether or not the ModmailConversation is a private
-                            mod conversation.
-    ``last_mod_update``     Time of the last mod message reply, represented in
-                            the `ISO 8601`_ standard with timezone.
-    ``last_updated``        Time of the last message reply, represented in
-                            the `ISO 8601`_ standard with timezone.
-    ``last_user_update``    Time of the last user message reply, represented in
-                            the `ISO 8601`_ standard with timezone.
+    ``is_highlighted``      Whether or not the ModmailConversation is highlighted.
+    ``is_internal``         Whether or not the ModmailConversation is a private mod
+                            conversation.
+    ``last_mod_update``     Time of the last mod message reply, represented in the
+                            `ISO 8601`_ standard with timezone.
+    ``last_updated``        Time of the last message reply, represented in the
+                            `ISO 8601`_ standard with timezone.
+    ``last_user_update``    Time of the last user message reply, represented in the
+                            `ISO 8601`_ standard with timezone.
     ``num_messages``        The number of messages in the ModmailConversation.
-    ``obj_ids``             Provides a list of dictionaries representing
-                            mod actions on the ModmailConversation. Each dict
-                            contains attributes of "key" and "id". The key can
-                            be either "messages" or "ModAction". ModAction
-                            represents archiving/highlighting etc.
-    ``owner``               Provides an instance of :class:`.Subreddit`. The
-                            subreddit that the ModmailConversation belongs to.
+    ``obj_ids``             Provides a list of dictionaries representing mod actions on
+                            the ModmailConversation. Each dict contains attributes of
+                            "key" and "id". The key can be either "messages" or
+                            "ModAction". ModAction represents archiving/highlighting
+                            etc.
+    ``owner``               Provides an instance of :class:`.Subreddit`. The subreddit
+                            that the ModmailConversation belongs to.
     ``participant``         Provides an instance of :class:`.Redditor`. The
                             participating user in the ModmailConversation.
     ``subject``             The subject of the ModmailConversation.
-    ======================= ===================================================
+    ======================= ============================================================
 
 
     .. _ISO 8601: https://en.wikipedia.org/wiki/ISO_8601
@@ -89,14 +86,17 @@ class ModmailConversation(RedditBase):
 
     @classmethod
     def parse(  # pylint: disable=arguments-differ
-        cls, data: Dict[str, Any], reddit: "Reddit", convert_objects: bool = True,
+        cls,
+        data: Dict[str, Any],
+        reddit: "praw.Reddit",
+        convert_objects: bool = True,
     ):
         """Return an instance of ModmailConversation from ``data``.
 
         :param data: The structured data.
         :param reddit: An instance of :class:`.Reddit`.
-        :param convert_objects: If True, convert message and mod action data
-            into objects (default: True).
+        :param convert_objects: If True, convert message and mod action data into
+            objects (default: True).
 
         """
         conversation = data["conversation"]
@@ -119,24 +119,24 @@ class ModmailConversation(RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
+        reddit: "praw.Reddit",
         id: Optional[str] = None,  # pylint: disable=redefined-builtin
         mark_read: bool = False,
         _data: Optional[Dict[str, Any]] = None,
     ):
         """Construct an instance of the ModmailConversation object.
 
-        :param mark_read: If True, conversation is marked as read
-            (default: False).
+        :param mark_read: If True, conversation is marked as read (default: False).
 
         """
-        super().__init__(reddit, _data=_data)
         if bool(id) == bool(_data):
             raise TypeError("Either `id` or `_data` must be provided.")
 
         if id:
             self.id = id
 
+        super().__init__(reddit, _data=_data)
+
         self._info_params = {"markRead": True} if mark_read else None
 
     def _build_conversation_list(self, other_conversations):
@@ -145,7 +145,7 @@ class ModmailConversation(RedditBase):
         return ",".join(conversation.id for conversation in conversations)
 
     def _fetch_info(self):
-        return ("modmail_conversation", {"id": self.id}, self._info_params)
+        return "modmail_conversation", {"id": self.id}, self._info_params
 
     def _fetch_data(self):
         name, fields, params = self._fetch_info()
@@ -165,7 +165,7 @@ class ModmailConversation(RedditBase):
 
         .. code-block:: python
 
-           reddit.subreddit("redditdev").modmail("2gmz").archive()
+            reddit.subreddit("redditdev").modmail("2gmz").archive()
 
         """
         self._reddit.post(API_PATH["modmail_archive"].format(id=self.id))
@@ -177,40 +177,54 @@ class ModmailConversation(RedditBase):
 
         .. code-block:: python
 
-           reddit.subreddit("redditdev").modmail("2gmz").highlight()
+            reddit.subreddit("redditdev").modmail("2gmz").highlight()
 
         """
         self._reddit.post(API_PATH["modmail_highlight"].format(id=self.id))
 
-    def mute(self):
+    def mute(self, num_days=3):
         """Mute the non-mod user associated with the conversation.
 
+        :param num_days: Duration of mute in days. Valid options are 3, 7, or 28.
+            (default: 3)
+
         For example:
 
         .. code-block:: python
 
-           reddit.subreddit("redditdev").modmail("2gmz").mute()
+            reddit.subreddit("redditdev").modmail("2gmz").mute()
+
+        To mute for 7 days:
+
+        .. code-block:: python
+
+            reddit.subreddit("redditdev").modmail("2gmz").mute(7)
 
         """
-        self._reddit.request("POST", API_PATH["modmail_mute"].format(id=self.id))
+        if num_days != 3:  # no need to pass params if it's the default
+            params = {"num_hours": num_days * 24}
+        else:
+            params = {}
+        self._reddit.request(
+            "POST", API_PATH["modmail_mute"].format(id=self.id), params=params
+        )
 
     def read(
         self, other_conversations: Optional[List["ModmailConversation"]] = None
     ):  # noqa: D207, D301
         """Mark the conversation(s) as read.
 
-        :param other_conversations: A list of other conversations to mark
-            (default: None).
+        :param other_conversations: A list of other conversations to mark (default:
+            None).
 
         For example, to mark the conversation as read along with other recent
         conversations from the same user:
 
         .. code-block:: python
 
-           subreddit = reddit.subreddit("redditdev")
-           conversation = subreddit.modmail.conversation("2gmz")
-           conversation.read(
-                            other_conversations=conversation.user.recent_convos)
+            subreddit = reddit.subreddit("redditdev")
+            conversation = subreddit.modmail.conversation("2gmz")
+            conversation.read(other_conversations=conversation.user.recent_convos)
 
         """
         data = {"conversationIds": self._build_conversation_list(other_conversations)}
@@ -220,25 +234,24 @@ class ModmailConversation(RedditBase):
         """Reply to the conversation.
 
         :param body: The Markdown formatted content for a message.
-        :param author_hidden: When True, author is hidden from non-moderators
-            (default: False).
-        :param internal: When True, message is a private moderator note,
-            hidden from non-moderators (default: False).
-        :returns: A :class:`~.ModmailMessage` object for the newly created
-            message.
+        :param author_hidden: When True, author is hidden from non-moderators (default:
+            False).
+        :param internal: When True, message is a private moderator note, hidden from
+            non-moderators (default: False).
+        :returns: A :class:`~.ModmailMessage` object for the newly created message.
 
         For example, to reply to the non-mod user while hiding your username:
 
         .. code-block:: python
 
-           conversation = reddit.subreddit("redditdev").modmail("2gmz")
-           conversation.reply("Message body", author_hidden=True)
+            conversation = reddit.subreddit("redditdev").modmail("2gmz")
+            conversation.reply("Message body", author_hidden=True)
 
         To create a private moderator note on the conversation:
 
         .. code-block:: python
 
-           conversation.reply("Message body", internal=True)
+            conversation.reply("Message body", internal=True)
 
         """
         data = {
@@ -260,7 +273,7 @@ class ModmailConversation(RedditBase):
 
         .. code-block:: python
 
-           reddit.subreddit("redditdev").modmail("2gmz").unarchive()
+            reddit.subreddit("redditdev").modmail("2gmz").unarchive()
 
         """
         self._reddit.post(API_PATH["modmail_unarchive"].format(id=self.id))
@@ -272,7 +285,7 @@ class ModmailConversation(RedditBase):
 
         .. code-block:: python
 
-           reddit.subreddit("redditdev").modmail("2gmz").unhighlight()
+            reddit.subreddit("redditdev").modmail("2gmz").unhighlight()
 
         """
         self._reddit.delete(API_PATH["modmail_highlight"].format(id=self.id))
@@ -284,7 +297,7 @@ class ModmailConversation(RedditBase):
 
         .. code-block:: python
 
-           reddit.subreddit("redditdev").modmail("2gmz").unmute()
+            reddit.subreddit("redditdev").modmail("2gmz").unmute()
 
         """
         self._reddit.request("POST", API_PATH["modmail_unmute"].format(id=self.id))
@@ -294,18 +307,17 @@ class ModmailConversation(RedditBase):
     ):  # noqa: D207, D301
         """Mark the conversation(s) as unread.
 
-        :param other_conversations: A list of other conversations to mark
-            (default: None).
+        :param other_conversations: A list of other conversations to mark (default:
+            None).
 
         For example, to mark the conversation as unread along with other recent
         conversations from the same user:
 
         .. code-block:: python
 
-           subreddit = reddit.subreddit("redditdev")
-           conversation = subreddit.modmail.conversation("2gmz")
-           conversation.unread(\
-other_conversations=conversation.user.recent_convos)
+            subreddit = reddit.subreddit("redditdev")
+            conversation = subreddit.modmail.conversation("2gmz")
+            conversation.unread(other_conversations=conversation.user.recent_convos)
 
         """
         data = {"conversationIds": self._build_conversation_list(other_conversations)}
