@@ -11,7 +11,7 @@ from .redditor import Redditor
 from .subreddit import Subreddit, SubredditStream
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
+    from .... import praw
 
 
 class Multireddit(SubredditListingMixin, RedditBase):
@@ -21,33 +21,33 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
+    ======================= ============================================================
     Attribute               Description
-    ======================= ===================================================
-    ``can_edit``            A ``bool`` representing whether or not the
-                            authenticated user may edit the multireddit.
-    ``copied_from``         The multireddit that the multireddit was copied
-                            from, if it exists, otherwise ``None``.
+    ======================= ============================================================
+    ``can_edit``            A ``bool`` representing whether or not the authenticated
+                            user may edit the multireddit.
+    ``copied_from``         The multireddit that the multireddit was copied from, if it
+                            exists, otherwise ``None``.
     ``created_utc``         When the multireddit was created, in `Unix Time`_.
     ``description_html``    The description of the multireddit, as HTML.
     ``description_md``      The description of the multireddit, as Markdown.
     ``display_name``        The display name of the multireddit.
     ``name``                The name of the multireddit.
-    ``over_18``             A ``bool`` representing whether or not the
-                            multireddit is restricted for users over 18.
-    ``subreddits``          A ``list`` of :class:`.Subreddit`\ s that make up
-                            the multireddit.
-    ``visibility``          The visibility of the multireddit, either
-                            ``private``, ``public``, or ``hidden``.
-    ======================= ===================================================
+    ``over_18``             A ``bool`` representing whether or not the multireddit is
+                            restricted for users over 18.
+    ``subreddits``          A ``list`` of :class:`.Subreddit`\ s that make up the
+                            multireddit.
+    ``visibility``          The visibility of the multireddit, either ``private``,
+                            ``public``, or ``hidden``.
+    ======================= ============================================================
 
     .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
+
     """
 
     STR_FIELD = "path"
@@ -74,33 +74,32 @@ class Multireddit(SubredditListingMixin, RedditBase):
     def stream(self) -> SubredditStream:
         """Provide an instance of :class:`.SubredditStream`.
 
-        Streams can be used to indefinitely retrieve new comments made to a
-        multireddit, like:
+        Streams can be used to indefinitely retrieve new comments made to a multireddit,
+        like:
 
         .. code-block:: python
 
-           for comment in reddit.multireddit("spez", "fun").stream.comments():
-               print(comment)
+            for comment in reddit.multireddit("spez", "fun").stream.comments():
+                print(comment)
 
-        Additionally, new submissions can be retrieved via the stream. In the
-        following example all new submissions to the multireddit are fetched:
+        Additionally, new submissions can be retrieved via the stream. In the following
+        example all new submissions to the multireddit are fetched:
 
         .. code-block:: python
 
-           for submission in reddit.multireddit("bboe",
-                                                "games").stream.submissions():
-               print(submission)
+            for submission in reddit.multireddit("bboe", "games").stream.submissions():
+                print(submission)
 
         """
         return SubredditStream(self)
 
-    def __init__(self, reddit: "Reddit", _data: Dict[str, Any]):
+    def __init__(self, reddit: "praw.Reddit", _data: Dict[str, Any]):
         """Construct an instance of the Multireddit object."""
         self.path = None
         super().__init__(reddit, _data=_data)
         self._author = Redditor(reddit, self.path.split("/", 3)[2])
         self._path = API_PATH["multireddit"].format(multi=self.name, user=self._author)
-        self.path = "/" + self._path[:-1]  # Prevent requests for path
+        self.path = f"/{self._path[:-1]}"  # Prevent requests for path
         if "subreddits" in self.__dict__:
             self.subreddits = [Subreddit(reddit, x["name"]) for x in self.subreddits]
 
@@ -123,7 +122,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
         self.__dict__.update(other.__dict__)
         self._fetched = True
 
-    def add(self, subreddit: "Subreddit"):
+    def add(self, subreddit: "praw.models.Subreddit"):
         """Add a subreddit to this multireddit.
 
         :param subreddit: The subreddit to add to this multi.
@@ -132,7 +131,7 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
         .. code-block:: python
 
-            subreddit=reddit.subreddit("test")
+            subreddit = reddit.subreddit("test")
             reddit.multireddit("bboe", "test").add(subreddit)
 
         """
@@ -142,13 +141,13 @@ class Multireddit(SubredditListingMixin, RedditBase):
         self._reddit.put(url, data={"model": dumps({"name": str(subreddit)})})
         self._reset_attributes("subreddits")
 
-    def copy(self, display_name: Optional[str] = None) -> "Multireddit":
+    def copy(self, display_name: Optional[str] = None) -> "praw.models.Multireddit":
         """Copy this multireddit and return the new multireddit.
 
-        :param display_name: (optional) The display name for the copied
-            multireddit. Reddit will generate the ``name`` field from this
-            display name. When not provided the copy will use the same display
-            name and name as this multireddit.
+        :param display_name: (optional) The display name for the copied multireddit.
+            Reddit will generate the ``name`` field from this display name. When not
+            provided the copy will use the same display name and name as this
+            multireddit.
 
         To copy the multireddit ``bboe/test`` with a name of ``testing``:
 
@@ -186,20 +185,18 @@ class Multireddit(SubredditListingMixin, RedditBase):
         )
         self._reddit.delete(path)
 
-    def remove(self, subreddit: "Subreddit"):
+    def remove(self, subreddit: "praw.models.Subreddit"):
         """Remove a subreddit from this multireddit.
 
         :param subreddit: The subreddit to remove from this multi.
 
-        For example, to remove subreddit ``r/test`` from multireddit
-        ``bboe/test``:
+        For example, to remove subreddit ``r/test`` from multireddit ``bboe/test``:
 
         .. code-block:: python
 
-            subreddit=reddit.subreddit("test")
+            subreddit = reddit.subreddit("test")
             reddit.multireddit("bboe", "test").remove(subreddit)
 
-
         """
         url = API_PATH["multireddit_update"].format(
             multi=self.name, user=self._author, subreddit=subreddit
@@ -209,25 +206,26 @@ class Multireddit(SubredditListingMixin, RedditBase):
 
     def update(
         self,
-        **updated_settings: Union[str, List[Union[str, Subreddit, Dict[str, str]]]]
+        **updated_settings: Union[
+            str, List[Union[str, "praw.models.Subreddit", Dict[str, str]]]
+        ],
     ):
         """Update this multireddit.
 
-        Keyword arguments are passed for settings that should be updated. They
-        can any of:
+        Keyword arguments are passed for settings that should be updated. They can any
+        of:
 
-        :param display_name: The display name for this multireddit. Must be no
-            longer than 50 characters.
+        :param display_name: The display name for this multireddit. Must be no longer
+            than 50 characters.
         :param subreddits: Subreddits for this multireddit.
-        :param description_md: Description for this multireddit, formatted in
-            Markdown.
-        :param icon_name: Can be one of: ``art and design``, ``ask``,
-            ``books``, ``business``, ``cars``, ``comics``, ``cute animals``,
-            ``diy``, ``entertainment``, ``food and drink``, ``funny``,
-            ``games``, ``grooming``, ``health``, ``life advice``, ``military``,
-            ``models pinup``, ``music``, ``news``, ``philosophy``, ``pictures
-            and gifs``, ``science``, ``shopping``, ``sports``, ``style``,
-            ``tech``, ``travel``, ``unusual stories``, ``video``, or ``None``.
+        :param description_md: Description for this multireddit, formatted in Markdown.
+        :param icon_name: Can be one of: ``art and design``, ``ask``, ``books``,
+            ``business``, ``cars``, ``comics``, ``cute animals``, ``diy``,
+            ``entertainment``, ``food and drink``, ``funny``, ``games``, ``grooming``,
+            ``health``, ``life advice``, ``military``, ``models pinup``, ``music``,
+            ``news``, ``philosophy``, ``pictures and gifs``, ``science``, ``shopping``,
+            ``sports``, ``style``, ``tech``, ``travel``, ``unusual stories``, ``video``,
+            or ``None``.
         :param key_color: RGB hex color code of the form ``"#FFFFFF"``.
         :param visibility: Can be one of: ``hidden``, ``private``, ``public``.
         :param weighting_scheme: Can be one of: ``classic``, ``fresh``.
