@@ -8,19 +8,18 @@ from .base import RedditBase
 from .redditor import Redditor
 
 if TYPE_CHECKING:  # pragma: no cover
-    from ... import Reddit
-    from .subreddit import Subreddit
+    from .... import praw
 
 
 class WikiPageModeration:
     """Provides a set of moderation functions for a WikiPage.
 
-    For example, to add ``spez`` as an editor on the wikipage ``praw_test``
-    try:
+    For example, to add ``spez`` as an editor on the wikipage ``praw_test`` try:
 
     .. code-block:: python
 
         reddit.subreddit("test").wiki["praw_test"].mod.add("spez")
+
     """
 
     def __init__(self, wikipage: "WikiPage"):
@@ -31,17 +30,17 @@ class WikiPageModeration:
         """
         self.wikipage = wikipage
 
-    def add(self, redditor: Redditor):
+    def add(self, redditor: "praw.models.Redditor"):
         """Add an editor to this WikiPage.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or
-            :class:`~.Redditor` instance.
+        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
+            instance.
 
         To add ``"spez"`` as an editor on the wikipage ``"praw_test"`` try:
 
         .. code-block:: python
 
-           reddit.subreddit("test").wiki["praw_test"].mod.add("spez")
+            reddit.subreddit("test").wiki["praw_test"].mod.add("spez")
 
         """
         data = {"page": self.wikipage.name, "username": str(redditor)}
@@ -50,17 +49,17 @@ class WikiPageModeration:
         )
         self.wikipage._reddit.post(url, data=data)
 
-    def remove(self, redditor: Redditor):
+    def remove(self, redditor: "praw.models.Redditor"):
         """Remove an editor from this WikiPage.
 
-        :param redditor: A redditor name (e.g., ``"spez"``) or
-            :class:`~.Redditor` instance.
+        :param redditor: A redditor name (e.g., ``"spez"``) or :class:`~.Redditor`
+            instance.
 
         To remove ``"spez"`` as an editor on the wikipage ``"praw_test"`` try:
 
         .. code-block:: python
 
-           reddit.subreddit("test").wiki["praw_test"].mod.remove("spez")
+            reddit.subreddit("test").wiki["praw_test"].mod.remove("spez")
 
         """
         data = {"page": self.wikipage.name, "username": str(redditor)}
@@ -83,19 +82,17 @@ class WikiPageModeration:
 
         :param listed: (boolean) Show this page on page list.
         :param permlevel: (int) Who can edit this page? (0) use subreddit wiki
-            permissions, (1) only approved wiki contributors for this page may
-            edit (see :meth:`.WikiPageModeration.add`), (2) only mods may edit
-            and view
+            permissions, (1) only approved wiki contributors for this page may edit (see
+            :meth:`.WikiPageModeration.add`), (2) only mods may edit and view
         :param other_settings: Additional keyword arguments to pass.
         :returns: The updated WikiPage settings.
 
-        To set the wikipage ``praw_test`` in ``/r/test`` to mod only and
-        disable it from showing in the page list, try:
+        To set the wikipage ``praw_test`` in ``r/test`` to mod only and disable it from
+        showing in the page list, try:
 
         .. code-block:: python
 
-           reddit.subreddit("test").wiki["praw_test"].mod.update(listed=False,
-                                                                 permlevel=2)
+            reddit.subreddit("test").wiki["praw_test"].mod.update(listed=False, permlevel=2)
 
         """
         other_settings.update({"listed": listed, "permlevel": permlevel})
@@ -110,33 +107,37 @@ class WikiPage(RedditBase):
 
     **Typical Attributes**
 
-    This table describes attributes that typically belong to objects of this
-    class. Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a
-    guarantee that these attributes will always be present, nor is this list
-    necessarily complete.
+    This table describes attributes that typically belong to objects of this class.
+    Since attributes are dynamically provided (see
+    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
+    these attributes will always be present, nor is this list necessarily complete.
 
-    ======================= ===================================================
+    ======================= ============================================================
     Attribute               Description
-    ======================= ===================================================
+    ======================= ============================================================
     ``content_html``        The contents of the wiki page, as HTML.
     ``content_md``          The contents of the wiki page, as Markdown.
-    ``may_revise``          A ``bool`` representing whether or not the
-                            authenticated user may edit the wiki page.
+    ``may_revise``          A ``bool`` representing whether or not the authenticated
+                            user may edit the wiki page.
     ``name``                The name of the wiki page.
-    ``revision_by``         The :class:`.Redditor` who authored this
-                            revision of the wiki page.
+    ``revision_by``         The :class:`~.Redditor` who authored this revision of the
+                            wiki page.
     ``revision_date``       The time of this revision, in `Unix Time`_.
-    ``subreddit``           The :class:`.Subreddit` this wiki page belongs to.
-    ======================= ===================================================
+    ``subreddit``           The :class:`~.Subreddit` this wiki page belongs to.
+    ======================= ============================================================
 
     .. _Unix Time: https://en.wikipedia.org/wiki/Unix_time
+
     """
 
     __hash__ = RedditBase.__hash__
 
     @staticmethod
-    def _revision_generator(subreddit, url, generator_kwargs):
+    def _revision_generator(
+        subreddit: "praw.models.Subreddit", url: str, generator_kwargs: Dict[str, Any]
+    ) -> Generator[
+        Dict[str, Optional[Union[Redditor, "WikiPage", str, int, bool]]], None, None
+    ]:
         for revision in ListingGenerator(subreddit._reddit, url, **generator_kwargs):
             if revision["author"] is not None:
                 revision["author"] = Redditor(
@@ -151,8 +152,7 @@ class WikiPage(RedditBase):
     def mod(self) -> WikiPageModeration:
         """Provide an instance of :class:`.WikiPageModeration`.
 
-        For example, to add ``spez`` as an editor on the wikipage ``praw_test``
-        try:
+        For example, to add ``spez`` as an editor on the wikipage ``praw_test`` try:
 
         .. code-block:: python
 
@@ -163,32 +163,33 @@ class WikiPage(RedditBase):
 
     def __init__(
         self,
-        reddit: "Reddit",
-        subreddit: "Subreddit",
+        reddit: "praw.Reddit",
+        subreddit: "praw.models.Subreddit",
         name: str,
         revision: Optional[str] = None,
         _data: Optional[Dict[str, Any]] = None,
     ):
         """Construct an instance of the WikiPage object.
 
-        :param revision: A specific revision ID to fetch. By default, fetches
-            the most recent revision.
+        :param revision: A specific revision ID to fetch. By default, fetches the most
+            recent revision.
 
         """
         self.name = name
         self._revision = revision
         self.subreddit = subreddit
-        super().__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data, _str_field=False)
 
     def __repr__(self) -> str:
         """Return an object initialization representation of the instance."""
-        return "{}(subreddit={!r}, name={!r})".format(
-            self.__class__.__name__, self.subreddit, self.name
+        return (
+            f"{self.__class__.__name__}(subreddit={self.subreddit!r},"
+            f" name={self.name!r})"
         )
 
     def __str__(self) -> str:
         """Return a string representation of the instance."""
-        return "{}/{}".format(self.subreddit, self.name)
+        return f"{self.subreddit}/{self.name}"
 
     def _fetch_info(self):
         return (
@@ -219,8 +220,8 @@ class WikiPage(RedditBase):
         :param reason: (Optional) The reason for the revision.
         :param other_settings: Additional keyword arguments to pass.
 
-        For example, to replace the first wiki page of ``r/test`` with the
-        phrase ``test wiki page``:
+        For example, to replace the first wiki page of ``r/test`` with the phrase ``test
+        wiki page``:
 
         .. code-block:: python
 
@@ -230,17 +231,18 @@ class WikiPage(RedditBase):
         """
         other_settings.update({"content": content, "page": self.name, "reason": reason})
         self._reddit.post(
-            API_PATH["wiki_edit"].format(subreddit=self.subreddit), data=other_settings,
+            API_PATH["wiki_edit"].format(subreddit=self.subreddit),
+            data=other_settings,
         )
 
     def revision(self, revision: str):
         """Return a specific version of this page by revision ID.
 
-        To view revision ``[ID]`` of ``"praw_test"`` in ``/r/test``:
+        To view revision ``[ID]`` of ``"praw_test"`` in ``r/test``:
 
         .. code-block:: python
 
-           page = reddit.subreddit("test").wiki["praw_test"].revision("[ID]")
+            page = reddit.subreddit("test").wiki["praw_test"].revision("[ID]")
 
         """
         return WikiPage(self.subreddit._reddit, self.subreddit, self.name, revision)
@@ -253,19 +255,19 @@ class WikiPage(RedditBase):
         Additional keyword arguments are passed in the initialization of
         :class:`.ListingGenerator`.
 
-        To view the wiki revisions for ``"praw_test"`` in ``/r/test`` try:
+        To view the wiki revisions for ``"praw_test"`` in ``r/test`` try:
 
         .. code-block:: python
 
-           for item in reddit.subreddit("test").wiki["praw_test"].revisions():
-               print(item)
+            for item in reddit.subreddit("test").wiki["praw_test"].revisions():
+                print(item)
 
         To get :class:`.WikiPage` objects for each revision:
 
         .. code-block:: python
 
-           for item in reddit.subreddit("test").wiki["praw_test"].revisions():
-               print(item["page"])
+            for item in reddit.subreddit("test").wiki["praw_test"].revisions():
+                print(item["page"])
 
         """
         url = API_PATH["wiki_page_revisions"].format(
