@@ -1,12 +1,14 @@
 """Provides the Objector class."""
 
-from typing import Any, Dict, List, Optional, TypeVar, Union
+from json import loads
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 from .exceptions import ClientException, RedditAPIException
 from .models.reddit.base import RedditBase
 from .util import snake_case_keys
 
-Reddit = TypeVar("Reddit")
+if TYPE_CHECKING:  # pragma: no cover
+    from ... import praw
 
 
 class Objector:
@@ -19,14 +21,13 @@ class Objector:
         """Convert JSON response into an error object.
 
         :param data: The dict to be converted.
-        :returns: An instance of :class:`~.RedditAPIException`, or ``None`` if
-            ``data`` doesn't fit this model.
+        :returns: An instance of :class:`~.RedditAPIException`, or ``None`` if ``data``
+            doesn't fit this model.
 
         """
         if isinstance(data, list):
-            # Fetching a Submission returns a list (of two items).
-            # Although it's handled manually in `Submission._fetch()`,
-            # assume it's a possibility here.
+            # Fetching a Submission returns a list (of two items). Although it's handled
+            # manually in `Submission._fetch()`, assume it's a possibility here.
             return None
 
         errors = data.get("json", {}).get("errors")
@@ -44,9 +45,7 @@ class Objector:
         if error:
             raise error
 
-    def __init__(
-        self, reddit: Reddit, parsers: Optional[Dict[str, Any]] = None
-    ):
+    def __init__(self, reddit: "praw.Reddit", parsers: Optional[Dict[str, Any]] = None):
         """Initialize an Objector instance.
 
         :param reddit: An instance of :class:`~.Reddit`.
@@ -72,6 +71,9 @@ class Objector:
             # Modmail message
             data = snake_case_keys(data)
             parser = self.parsers["ModmailMessage"]
+        elif {"kind", "short_name", "violation_reason"}.issubset(data):
+            # This is a Rule
+            parser = self.parsers["rule"]
         elif {"isAdmin", "isDeleted"}.issubset(data):
             # Modmail author
             data = snake_case_keys(data)
@@ -113,12 +115,24 @@ class Objector:
             parser = self.parsers[self._reddit.config.kinds["comment"]]
         elif "collection_id" in data.keys():
             parser = self.parsers["Collection"]
+        elif {"moderators", "moderatorIds", "allUsersLoaded", "subredditId"}.issubset(
+            data
+        ):
+            data = snake_case_keys(data)
+            moderators = []
+            for mod_id in data["moderator_ids"]:
+                mod = snake_case_keys(data["moderators"][mod_id])
+                mod["mod_permissions"] = list(mod["mod_permissions"].keys())
+                moderators.append(mod)
+            data["moderators"] = moderators
+            parser = self.parsers["moderator-list"]
+        elif "username" in data.keys():
+            data["name"] = data.pop("username")
+            parser = self.parsers[self._reddit.config.kinds["redditor"]]
         else:
             if "user" in data:
                 parser = self.parsers[self._reddit.config.kinds["redditor"]]
-                data["user"] = parser.parse(
-                    {"name": data["user"]}, self._reddit
-                )
+                data["user"] = parser.parse({"name": data["user"]}, self._reddit)
             return data
         return parser.parse(data, self._reddit)
 
@@ -128,8 +142,8 @@ class Objector:
         """Create RedditBase objects from data.
 
         :param data: The structured data.
-        :returns: An instance of :class:`~.RedditBase`, or ``None`` if
-            given ``data`` is ``None``.
+        :returns: An instance of :class:`~.RedditBase`, or ``None`` if given ``data`` is
+            ``None``.
 
         """
         # pylint: disable=too-many-return-statements
@@ -137,6 +151,10 @@ class Objector:
             return None
         if isinstance(data, list):
             return [self.objectify(item) for item in data]
+        if "json" in data and "errors" in data["json"]:
+            errors = data["json"]["errors"]
+            if len(errors) > 0:
+                raise RedditAPIException(errors)
         if "kind" in data and (
             "shortName" in data or data["kind"] in ("menu", "moderators")
         ):
@@ -151,17 +169,25 @@ class Objector:
                 return data
             if "things" in data["json"]["data"]:  # Submission.reply
                 return self.objectify(data["json"]["data"]["things"])
+            if "rules" in data["json"]["data"]:
+                return self.objectify(loads(data["json"]["data"]["rules"]))
             if "url" in data["json"]["data"]:  # Subreddit.submit
                 # The URL is the URL to the submission, so it's removed.
                 del data["json"]["data"]["url"]
                 parser = self.parsers[self._reddit.config.kinds["submission"]]
+                if data["json"]["data"]["id"].startswith(
+                    f"{self._reddit.config.kinds['submission']}_"
+                ):
+                    # With polls, Reddit returns a fullname but calls it an "id". This
+                    # fixes this by coercing the fullname into an id.
+                    data["json"]["data"]["id"] = data["json"]["data"]["id"].split(
+                        "_", 1
+                    )[1]
             else:
                 parser = self.parsers["LiveUpdateEvent"]
             return parser.parse(data["json"]["data"], self._reddit)
-        if "json" in data and "errors" in data["json"]:
-            errors = data["json"]["errors"]
-            if len(errors) > 0:
-                raise RedditAPIException(errors)
+        if "rules" in data:
+            return self.objectify(data["rules"])
         elif isinstance(data, dict):
             return self._objectify_dict(data)
 
