@@ -7,7 +7,17 @@ import sys
 import time
 from itertools import islice
 from logging import getLogger
-from typing import IO, Any, Dict, Generator, Iterable, Optional, Type, Union
+from typing import (
+    IO,
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Generator,
+    Iterable,
+    Optional,
+    Type,
+    Union,
+)
 from warnings import warn
 
 from prawcore import (
@@ -32,6 +42,7 @@ from .exceptions import (
     RedditAPIException,
 )
 from .objector import Objector
+from .util.token_manager import BaseTokenManager
 
 try:
     from update_checker import update_check
@@ -40,6 +51,8 @@ try:
 except ImportError:  # pragma: no cover
     UPDATE_CHECKER_MISSING = True
 
+if TYPE_CHECKING:  # pragma: no cover
+    from .. import praw
 
 Comment = models.Comment
 Redditor = models.Redditor
@@ -139,6 +152,8 @@ class Reddit:
         config_interpolation: Optional[str] = None,
         requestor_class: Optional[Type[Requestor]] = None,
         requestor_kwargs: Dict[str, Any] = None,
+        *,
+        token_manager: Optional[BaseTokenManager] = None,
         **config_settings: Union[str, bool],
     ):  # noqa: D207, D301
         """Initialize a Reddit instance.
@@ -154,6 +169,10 @@ class Reddit:
             set, use ``prawcore.Requestor`` (default: None).
         :param requestor_kwargs: Dictionary with additional keyword arguments used to
             initialize the requestor (default: None).
+        :param token_manager: When provided, the passed instance, a subclass of
+            :class:`.BaseTokenManager`, will manage tokens via two callback functions.
+            This parameter must be provided in order to work with refresh tokens
+            (default: None).
 
         Additional keyword arguments will be used to initialize the :class:`.Config`
         object. This can be used to specify configuration settings during instantiation
@@ -200,6 +219,7 @@ class Reddit:
         """
         self._core = self._authorized_core = self._read_only_core = None
         self._objector = None
+        self._token_manager = token_manager
         self._unique_counter = 0
         self._validate_on_submit = False
 
@@ -399,6 +419,29 @@ class Reddit:
             update_check(__package__, __version__)
             Reddit.update_checked = True
 
+    def _prepare_common_authorizer(self, authenticator):
+        if self._token_manager is not None:
+            if self.config._do_not_use_refresh_token != self.config.CONFIG_NOT_SET:
+                raise TypeError(
+                    "legacy ``refresh_token`` setting cannot be provided when providing"
+                    " ``token_manager``"
+                )
+
+            self._token_manager.reddit = self
+            authorizer = Authorizer(
+                authenticator,
+                post_refresh_callback=self._token_manager.post_refresh_callback,
+                pre_refresh_callback=self._token_manager.pre_refresh_callback,
+            )
+        elif self.config._do_not_use_refresh_token != self.config.CONFIG_NOT_SET:
+            authorizer = Authorizer(
+                authenticator, refresh_token=self.config._do_not_use_refresh_token
+            )
+        else:
+            self._core = self._read_only_core
+            return
+        self._core = self._authorized_core = session(authorizer)
+
     def _prepare_objector(self):
         mappings = {
             self.config.kinds["comment"]: models.Comment,
@@ -472,11 +515,8 @@ class Reddit:
                 authenticator, self.config.username, self.config.password
             )
             self._core = self._authorized_core = session(script_authorizer)
-        elif self.config.refresh_token:
-            authorizer = Authorizer(authenticator, self.config.refresh_token)
-            self._core = self._authorized_core = session(authorizer)
         else:
-            self._core = self._read_only_core
+            self._prepare_common_authorizer(authenticator)
 
     def _prepare_untrusted_prawcore(self, requestor):
         authenticator = UntrustedAuthenticator(
@@ -484,11 +524,7 @@ class Reddit:
         )
         read_only_authorizer = DeviceIDAuthorizer(authenticator)
         self._read_only_core = session(read_only_authorizer)
-        if self.config.refresh_token:
-            authorizer = Authorizer(authenticator, self.config.refresh_token)
-            self._core = self._authorized_core = session(authorizer)
-        else:
-            self._core = self._read_only_core
+        self._prepare_common_authorizer(authenticator)
 
     def comment(
         self,  # pylint: disable=invalid-name
@@ -533,8 +569,12 @@ class Reddit:
         self,
         fullnames: Optional[Iterable[str]] = None,
         url: Optional[str] = None,
-        subreddits: Optional[Iterable[Union[Subreddit, str]]] = None,
-    ) -> Generator[Union[Subreddit, Comment, Submission], None, None]:
+        subreddits: Optional[Iterable[Union["praw.models.Subreddit", str]]] = None,
+    ) -> Generator[
+        Union["praw.models.Subreddit", "praw.models.Comment", "praw.models.Submission"],
+        None,
+        None,
+    ]:
         """Fetch information about each item in ``fullnames``, ``url``, or ``subreddits``.
 
         :param fullnames: A list of fullnames for comments, submissions, and/or
@@ -577,11 +617,11 @@ class Reddit:
 
             api_parameter_name = "id" if is_using_fullnames else "sr_name"
 
-            def generator(fullnames):
+            def generator(names):
                 if is_using_fullnames:
-                    iterable = iter(ids_or_names)
+                    iterable = iter(names)
                 else:
-                    iterable = iter([str(item) for item in ids_or_names])
+                    iterable = iter([str(item) for item in names])
                 while True:
                     chunk = list(islice(iterable, 100))
                     if not chunk:
@@ -590,7 +630,7 @@ class Reddit:
                     for result in self.get(API_PATH["info"], params=params):
                         yield result
 
-            return generator(fullnames)
+            return generator(ids_or_names)
 
         def generator(url):
             params = {"url": url}
@@ -749,7 +789,7 @@ class Reddit:
         """
         return self._objectify_request(data=data, json=json, method="PUT", path=path)
 
-    def random_subreddit(self, nsfw: bool = False) -> Subreddit:
+    def random_subreddit(self, nsfw: bool = False) -> "praw.models.Subreddit":
         """Return a random lazy instance of :class:`~.Subreddit`.
 
         :param nsfw: Return a random NSFW (not safe for work) subreddit
@@ -766,8 +806,8 @@ class Reddit:
 
     def redditor(
         self, name: Optional[str] = None, fullname: Optional[str] = None
-    ) -> Redditor:
-        """Return a lazy instance of :class:`~.Redditor`.
+    ) -> "praw.models.Redditor":
+        """Return a lazy instance of :class:`.Redditor`.
 
         :param name: The name of the redditor.
         :param fullname: The fullname of the redditor, starting with ``t2_``.
@@ -837,11 +877,11 @@ class Reddit:
 
     def submission(  # pylint: disable=invalid-name,redefined-builtin
         self, id: Optional[str] = None, url: Optional[str] = None
-    ) -> Submission:
+    ) -> "praw.models.Submission":
         """Return a lazy instance of :class:`~.Submission`.
 
         :param id: A Reddit base36 submission ID, e.g., ``2gmzqe``.
-        :param url: A URL supported by :meth:`~praw.models.Submission.id_from_url`.`.
+        :param url: A URL supported by :meth:`~.Submission.id_from_url`.
 
         Either ``id`` or ``url`` can be provided, but not both.
 
